==> order-center-domain-2.0.9-CLOUD-TEST-20220409.043044-69-sources.jar: com/tydic/dyc/oc/model/order/qrybo/UocOrderStakeholderQryBo.java <==
package com.tydic.dyc.oc.model.order.qrybo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocOrderStakeholderQryBo
 * 说明:
 * 时间:2022/2/24 19:39
 * 作者:田桂银
 */
@Data
public class UocOrderStakeholderQryBo implements Serializable {

    private static final long serialVersionUID = -5069587144302771984L;

    @DocField(value = "三方信息id")
    private Long stakeholderId;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "采购方账套id")
    private String purAccount;

    @DocField(value = "采购方账套名称")
    private String purAccountName;

    @DocField(value = "采购方联系人电话")
    private String purMobile;

    @DocField(value = "采购方下单人用户id")
    private String purUserId;

    @DocField(value = "采购方下单人真实姓名")
    private String purName;

    @DocField(value = "采购方下单人登录名")
    private String purUserName;

    @DocField(value = "采购方公司id")
    private String purCompanyId;

    @DocField(value = "采购公司编码")
    private String purCompanyNo;

    @DocField(value = "采购方公司名称")
    private String purCompanyName;

    @DocField(value = "采购方机构id")
    private String purOrgId;

    @DocField(value = "采购方机构编码")
    private String purOrgNo;

    @DocField(value = "采购方机构名称")
    private String purOrgName;

    @DocField(value = "下单组织机构路径")
    private String purOrgPath;

    @DocField(value = "需方联系人名称")
    private String purNeedName;

    @DocField(value = "需方联系电话")
    private String purNeedMobile;

    @DocField(value = "供应商id")
    private String supId;

    @DocField(value = "供应商编码")
    private String supNo;

    @DocField(value = "供应商名称")
    private String supName;

    @DocField(value = "供应商联系人")
    private String supRelaName;

    @DocField(value = "供应商联系电话")
    private String supRelaMobile;

    @DocField(value = "运营单位机构id")
    private String proId;

    @DocField(value = "运营单位机构编码")
    private String proNo;

    @DocField(value = "运营机构名称")
    private String proName;

    @DocField(value = "运营机构机构树路径")
    private String proOrgPath;

    @DocField(value = "运营机构账户名称")
    private String proAccountName;

    @DocField(value = "运营机构账户")
    private String proAccount;

    @DocField(value = "运营机构联系人")
    private String proRelaName;

    @DocField(value = "运营机构联系电话")
    private String proRelaMobile;

    @DocField(value = "协议经办人id（配送专责）")
    private String proDeliveryId;

    @DocField(value = "协议经办人名字（配送专责）")
    private String proDeliveryName;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "排序")
    private String orderBy;


}

==> order-center-domain-3.1.0-CLOUD-TEST-20230731.024047-76-sources.jar: com/tydic/dyc/oc/model/order/qrybo/UocOrderStakeholderQryBo.java <==
package com.tydic.dyc.oc.model.order.qrybo;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocOrderStakeholderQryBo
 * 说明:
 * 时间:2022/2/24 19:39
 * 作者:田桂银
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocOrderStakeholderQryBo implements Serializable {

    private static final long serialVersionUID = -5069587144302771984L;

    //三方信息id")
    private Long stakeholderId;

    //订单id")
    private Long orderId;

    //采购方账套id")
    private String purAccount;

    //采购方账套名称")
    private String purAccountName;

    //采购方联系人电话")
    private String purMobile;

    //采购方下单人用户id")
    private String purUserId;

    //采购方下单人真实姓名")
    private String purName;

    //采购方下单人登录名")
    private String purUserName;

    //采购方公司id")
    private String purCompanyId;

    //采购公司编码")
    private String purCompanyNo;

    //采购方公司名称")
    private String purCompanyName;

    //采购方机构id")
    private String purOrgId;

    //采购方机构编码")
    private String purOrgNo;

    //采购方机构名称")
    private String purOrgName;

    //下单组织机构路径")
    private String purOrgPath;

    //需方联系人名称")
    private String purNeedName;

    //需方联系电话")
    private String purNeedMobile;

    //供应商id")
    private String supId;

    //供应商编码")
    private String supNo;

    //供应商名称")
    private String supName;

    //供应商联系人")
    private String supRelaName;

    //供应商联系电话")
    private String supRelaMobile;

    //运营单位机构id")
    private String proId;

    //运营单位机构编码")
    private String proNo;

    //运营机构名称")
    private String proName;

    //运营机构机构树路径")
    private String proOrgPath;

    //运营机构账户名称")
    private String proAccountName;

    //运营机构账户")
    private String proAccount;

    //运营机构联系人")
    private String proRelaName;

    //运营机构联系电话")
    private String proRelaMobile;

    //协议经办人id（配送专责）")
    private String proDeliveryId;

    //协议经办人名字（配送专责）")
    private String proDeliveryName;

    //更新时间")
    private Date updateTime;

    //更新工号")
    private String updateOperId;

    //备注")
    private String remark;

    //排序")
    private String orderBy;


}
